Сделать полную документацию
комманда генерации pdoc src/aiosmsactivate/client --output-dir docs
добавить объект арендного номера и функции ему
добавить метод wait_smscode для аренды

Почистить библиотеку от мусорных функций, привести к единому стилю, убрать всё лишнее, оставив полный функционал к сайту и перевести на полное ооп